import type { DefaultsMode } from "@smithy/smithy-client";
import type { Provider } from "@smithy/types";
/**
 * @internal
 */
export declare const DEFAULTS_MODE_OPTIONS: string[];
/**
 * @internal
 */
export interface ResolveDefaultsModeConfigOptions {
    defaultsMode?: DefaultsMode | Provider<DefaultsMode>;
}
